@@ -13,7 +13,10 @@ def image_mnist(image):
     mean, std = (0.1307,), (0.3081,) # MNIST dataset mean and std
     tensor = transforms.Normalize(mean=mean, std=std)(tensor)
 
-    # Add a batch dimension to the tensor and pass it through the model
-    tensor = tensor.unsqueeze(0)
+    # # Add a batch dimension to the tensor and pass it through the model
+    # tensor = tensor.unsqueeze(0)
+
+    # Flatten the tensor
+    tensor = tensor.view(1, -1)
     return tensor
 
